{% extends "base.html" %}
{% load i18n towel_form_tags %}

{% block title %}{% trans "Password reset" %} - {{ block.super }}{% endblock %}

{% block main %}
<div class="row">
  <div class="large-6 large-centered columns">
    <h1>{% trans "Password reset" %}</h1>
    {% include "towel/_messages.html" %}
    <form action="." method="post">
      <p>{% trans "Forgotten your password? Enter your email address below, and we'll email instructions for setting a new one." %}</p>

      {% csrf_token %}
      {% form_errors form %}
      {% form_item form.email %}

      <button type="submit" class="button">
        {% trans "Reset my password" %}</button>
    </form>
  </div>
</div>
{% endblock %}
