{% extends "base.html" %}
{% load i18n %}

{% block title %}{% trans "Password reset complete" %} - {{ block.super }}{% endblock %}

{% block main %}
<div class="row">
  <div class="large-6 large-centered columns">
    <h1>{% trans "Password reset complete" %}</h1>
    {% include "towel/_messages.html" %}

    <p>{% trans "Your password has been set.  You may go ahead and log in now." %}</p>
    <a href="{{ login_url }}" class="button">{% trans "Log in" %}</a>
  </div>
</div>
{% endblock %}
