<a class="ordering"
  href="{{ base_url }}?{{ querystring }}&o={{ descending|yesno:"-," }}{{ field }}">
  {% if used %}
    <i class="fi-arrow-{{ descending|yesno:"down,up" }}-arrow"></i>
  {% endif %}
  {{ title|default:field }}
</a>
