{% extends base_template|default:"base.html" %}

{% load i18n towel_form_tags verbose_name_tags %}

{% block title %}{{ title }}{% if block.super %} - {{ block.super }}{% endif %}{% endblock %}

{% block page-header %}
<h1>{{  title }}</h1>
{% endblock %}

{% block content %}
<form method="post" action="{{ request.get_full_path|default:"." }}"
  enctype="multipart/form-data">
{% csrf_token %}
{% form_errors form %}
{{ action_hidden_fields|safe }}

<fieldset>
  <label>{% trans "Items" %}</label>
  <div class="action-objects">
    <ul>
      {% for item in action_queryset %}
        <li>{{ item }}</li>
      {% endfor %}
    </ul>
  </div>
  {% for field in form %}
    {% if field.is_hidden %}{{ field }}
    {% else %}{% form_item field %}
    {% endif %}
  {% endfor %}
</fieldset>

<div class="form-actions">
    <input class="button" type="submit" value="{% trans "confirm"|capfirst %}">

    <a href="." class="button right">{% trans "cancel"|capfirst %}</a>
</div>

</form>
{% endblock %}
