{% extends "base.html" %}

{% load i18n towel_form_tags %}
{% load url from future %}

{% block title %}{% trans "Welcome!" %} - {{ block.super }}{% endblock %}

{% block main %}
<div class="row">
  <div class="large-6 large-centered columns">
    <h1>{% trans "Welcome!" %}</h1>
    {% include "towel/_messages.html" %}
    <form method="post" action=".">
      {% csrf_token %}
      {% form_errors form %}
      {% for field in form %}{% form_item field %}{% endfor %}

      <button type="submit" class="button">{% trans "Sign in" %}</button>
    </form>
  </div>
</div>
{% endblock %}
